ewa.buffutil

Package ewa :: Module buffutil |
[hide private]
[frames] | no frames]

# Module buffutil

source code

Functions | [hide private]
buff_chunk_string(s, bsize) | source code
buff_chunk_file(fp, end, bsize) | source code
buff_chunk_iterator(iterator, bsize) this adapts an iterator that yields chunks of one size to one that yields chunks of another | source code

Variables | [hide private]
| __package__ = `None`